@@ -1892,14 +1892,6 @@ class VariableClCheckUpdateLevel(Variable):
     """
     Проверять уровень обновления 
     при соединении с binhost
-    NOT IMPLEMENTED  YET
     """
     type = "bool"
-    value = "on"
-
-class VariableClUpdateMaxLevelFound(Variable):
-    """
-    Самый высокий уровень наиденный на зеркалах
-    """
-    type = "int"
-    value = "0"
\ No newline at end of file
+    value = "on"
\ No newline at end of file
